==> nodegit-0.2.4.tgz: package/src/reflog_entry.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/reflog_entry.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitReflogEntry::GitReflogEntry(git_reflog_entry *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitReflogEntry::~GitReflogEntry() {
   }

  void GitReflogEntry::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(New);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("ReflogEntry"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("ReflogEntry"), _constructor_template);
  }

  NAN_METHOD(GitReflogEntry::New) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitReflogEntry cannot be instantiated.");
     }

    GitReflogEntry* object = new GitReflogEntry(static_cast<git_reflog_entry *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitReflogEntry::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitReflogEntry::constructor_template)->NewInstance(2, argv));
  }

  git_reflog_entry *GitReflogEntry::GetValue() {
    return this->raw;
  }

  git_reflog_entry **GitReflogEntry::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitReflogEntry::constructor_template;

==> nodegit-0.2.5.tgz: package/src/reflog_entry.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/reflog_entry.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitReflogEntry::GitReflogEntry(git_reflog_entry *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitReflogEntry::~GitReflogEntry() {
   }

  void GitReflogEntry::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(JSNewFunction);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("ReflogEntry"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("ReflogEntry"), _constructor_template);
  }

  NAN_METHOD(GitReflogEntry::JSNewFunction) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitReflogEntry cannot be instantiated.");
     }

    GitReflogEntry* object = new GitReflogEntry(static_cast<git_reflog_entry *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitReflogEntry::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitReflogEntry::constructor_template)->NewInstance(2, argv));
  }

  git_reflog_entry *GitReflogEntry::GetValue() {
    return this->raw;
  }

  git_reflog_entry **GitReflogEntry::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitReflogEntry::constructor_template;
